@@ -558,6 +558,7 @@ if (typeof django_datatables === 'undefined') {
 
             this.initsetup = tablesetup
             this.filters = []
+            this.plugins = []
             this.table_id = html_id
 
             django_datatables.DataTables[html_id] = this
@@ -738,6 +739,9 @@ if (typeof django_datatables === 'undefined') {
             } else {
                 this.table.api().order([])
             }
+            for (var c=0; c<this.initsetup.colOptions.length;c++){
+                this.table.api().column(c).visible(this.initsetup.colOptions[c].hidden != true)
+            }
             this.table.api().draw()
         }
 
